Index: channels/chan_zap.c
===================================================================
RCS file: /usr/cvsroot/asterisk/channels/chan_zap.c,v
retrieving revision 1.268
diff -u -r1.268 chan_zap.c
--- channels/chan_zap.c	14 Jun 2004 21:40:57 -0000	1.268
+++ channels/chan_zap.c	16 Jun 2004 03:08:50 -0000
@@ -229,6 +229,7 @@
 static char idledial[AST_MAX_EXTENSION];
 static int overlapdial = 0;
 static struct ast_channel inuse = { "GR-303InUse" };
+static int resetinterval = RESET_INTERVAL;
 #endif
 
 /* Wait up to 16 seconds for first digit (FXO logic) */
@@ -332,7 +333,8 @@
 	int span;
 	int resetting;
 	int resetpos;
-	time_t lastreset;
+	time_t time2reset;
+	int resetinterval;
 	struct zt_pvt *pvts[MAX_CHANNELS];	/* Member channel pvt structs */
 	struct zt_pvt *crvs;				/* Member CRV structs */
 	struct zt_pvt *crvend;				/* Pointer to end of CRV structs */
@@ -5909,6 +5911,7 @@
 					pris[span].minunused = minunused;
 					pris[span].minidle = minidle;
 					pris[span].overlapdial = overlapdial;
+					pris[span].resetinterval = resetinterval;
 					strncpy(pris[span].idledial, idledial, sizeof(pris[span].idledial) - 1);
 					strncpy(pris[span].idleext, idleext, sizeof(pris[span].idleext) - 1);
 					
@@ -6602,7 +6605,11 @@
 		pri_reset(pri->pri, PVT_TO_CHANNEL(pri->pvts[pri->resetpos]));
 	} else {
 		pri->resetting = 0;
-		time(&pri->lastreset);
+		if (pri->resetinterval) {
+			time(&pri->time2reset); /* Is this required? */
+			pri->time2reset += pri->resetinterval;
+		} else
+			pri->time2reset = 0;
 	}
 	return 0;
 }
@@ -6693,7 +6700,7 @@
 				if (pri->resetpos < 0)
 					pri_check_restart(pri);
 			} else {
-				if (!pri->resetting && ((t - pri->lastreset) >= RESET_INTERVAL)) {
+				if (!pri->resetting && pri->time2reset && (t >= pri->time2reset)) {
 					pri->resetting = 1;
 					pri->resetpos = -1;
 				}
@@ -6861,11 +6868,10 @@
 				pri_find_dchan(pri);
 
 				/* Note presense of D-channel */
-				time(&pri->lastreset);
+				time(&pri->time2reset);
 
 				/* Restart in 5 seconds */
-				pri->lastreset -= RESET_INTERVAL;
-				pri->lastreset += 5;
+				pri->time2reset += 5;
 				pri->resetting = 0;
 				/* Take the channels from inalarm condition */
 				for (i=0; i<pri->numchans; i++)
@@ -8325,6 +8331,7 @@
 		}
 		v = v->next;
 	}
+	resetinterval = RESET_INTERVAL;
 #endif
 	v = ast_variable_browse(cfg, "channels");
 	while(v) {
@@ -8420,6 +8427,9 @@
 				}
 				chan = strsep(&c, ",");
 			}
+#ifdef ZAPATA_PRI
+			resetinterval = RESET_INTERVAL;
+#endif
 		} else if (!strcasecmp(v->name, "usedistinctiveringdetection")) {
 			if (ast_true(v->value))
 				usedistinctiveringdetection = 1;
@@ -8672,6 +8682,12 @@
 			}
 #endif
 #ifdef ZAPATA_PRI
+		} else if (!strcasecmp(v->name, "resetinterval")) {
+			x = atoi(v->value);
+			if (x < 0)
+				ast_log(LOG_WARNING, "Reset interval must be non-negative integer (currently %d)\n", x);
+			else
+				resetinterval = x;
 		} else if (!strcasecmp(v->name, "pridialplan")) {
 			if (!strcasecmp(v->value, "national")) {
 				dialplan = PRI_NATIONAL_ISDN + 1;
